Changelog
=========

0.1 (2014-03-05)
----------------

- Initial release.
- Added dependency to Products.PloneFormGen, collective.contentleadimage and plone.app.theming.
- Configure Plone email settings.
- Enable sitemap.xml.gz and DC metadata.
